# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class WorkspaceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeProject(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/DescribeProject",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.DescribeProjectOutput"),
            **kwargs,
        )

    def ListProjects(self, request, **kwargs):
        path = "/workspace/projects"

        return self.transport.request(
            name="eolymp.workspace.Workspace/ListProjects",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.ListProjectsOutput"),
            **kwargs,
        )

    def CreateProject(self, request, **kwargs):
        path = "/workspace/projects"

        return self.transport.request(
            name="eolymp.workspace.Workspace/CreateProject",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.CreateProjectOutput"),
            **kwargs,
        )

    def UpdateProject(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/UpdateProject",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.UpdateProjectOutput"),
            **kwargs,
        )

    def DeleteProject(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/DeleteProject",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.DeleteProjectOutput"),
            **kwargs,
        )

    def ListFiles(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)+"/files"

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/ListFiles",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.ListFilesOutput"),
            **kwargs,
        )

    def DescribeFile(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)+"/files/"+urllib.parse.quote(request.name)

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""
        request.name = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/DescribeFile",
            method="GET",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.DescribeFileOutput"),
            **kwargs,
        )

    def UploadFile(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)+"/files"

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/UploadFile",
            method="POST",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.UploadFileOutput"),
            **kwargs,
        )

    def RemoveFile(self, request, **kwargs):
        path = "/workspace/projects/"+urllib.parse.quote(request.project_id)+"/files/"+urllib.parse.quote(request.name)

        # Cleanup URL parameters to avoid any ambiguity
        request.project_id = ""
        request.name = ""

        return self.transport.request(
            name="eolymp.workspace.Workspace/RemoveFile",
            method="DELETE",
            url=self.url+path,
            path=path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.workspace.RemoveFileOutput"),
            **kwargs,
        )




from eolymp.judge import participant_pb2 as _participant_pb2
from eolymp.judge import reply_pb2 as _reply_pb2
from eolymp.judge import score_pb2 as _score_pb2
from eolymp.judge import submission_pb2 as _submission_pb2
from eolymp.judge import ticket_pb2 as _ticket_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParticipantCreatedEvent(_message.Message):
    __slots__ = ["participant"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    participant: _participant_pb2.Participant
    def __init__(self, participant: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ...) -> None: ...

class ParticipantDeletedEvent(_message.Message):
    __slots__ = ["participant"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    participant: _participant_pb2.Participant
    def __init__(self, participant: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ...) -> None: ...

class ParticipantUpdatedEvent(_message.Message):
    __slots__ = ["participant"]
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    participant: _participant_pb2.Participant
    def __init__(self, participant: _Optional[_Union[_participant_pb2.Participant, _Mapping]] = ...) -> None: ...

class RebuildScoreEvent(_message.Message):
    __slots__ = ["activity_id", "contest_id"]
    ACTIVITY_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    activity_id: str
    contest_id: str
    def __init__(self, contest_id: _Optional[str] = ..., activity_id: _Optional[str] = ...) -> None: ...

class ScoreUpdatedEvent(_message.Message):
    __slots__ = ["contest_id", "out_of_competition", "participant_id", "score"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    OUT_OF_COMPETITION_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    out_of_competition: bool
    participant_id: str
    score: _score_pb2.Score
    def __init__(self, contest_id: _Optional[str] = ..., participant_id: _Optional[str] = ..., out_of_competition: bool = ..., score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...

class SubmissionCompletedEvent(_message.Message):
    __slots__ = ["submission"]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    submission: _submission_pb2.Submission
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ...) -> None: ...

class TicketCreatedEvent(_message.Message):
    __slots__ = ["ticket"]
    TICKET_FIELD_NUMBER: _ClassVar[int]
    ticket: _ticket_pb2.Ticket
    def __init__(self, ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ...) -> None: ...

class TicketUpdatedEvent(_message.Message):
    __slots__ = ["reply", "ticket"]
    REPLY_FIELD_NUMBER: _ClassVar[int]
    TICKET_FIELD_NUMBER: _ClassVar[int]
    reply: _reply_pb2.Reply
    ticket: _ticket_pb2.Ticket
    def __init__(self, ticket: _Optional[_Union[_ticket_pb2.Ticket, _Mapping]] = ..., reply: _Optional[_Union[_reply_pb2.Reply, _Mapping]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CreateObjectInput(_message.Message):
    __slots__ = ["data"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class CreateObjectOutput(_message.Message):
    __slots__ = ["blob_ern", "blob_hash", "key"]
    BLOB_ERN_FIELD_NUMBER: _ClassVar[int]
    BLOB_HASH_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    blob_ern: str
    blob_hash: str
    key: str
    def __init__(self, key: _Optional[str] = ..., blob_ern: _Optional[str] = ..., blob_hash: _Optional[str] = ...) -> None: ...

class DescribeObjectInput(_message.Message):
    __slots__ = ["key"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    key: str
    def __init__(self, key: _Optional[str] = ...) -> None: ...

class DescribeObjectOutput(_message.Message):
    __slots__ = ["size"]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    size: int
    def __init__(self, size: _Optional[int] = ...) -> None: ...

class DownloadObjectInput(_message.Message):
    __slots__ = ["key", "offset", "size"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    key: str
    offset: int
    size: int
    def __init__(self, key: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class DownloadObjectOutput(_message.Message):
    __slots__ = ["data", "size"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    size: int
    def __init__(self, data: _Optional[bytes] = ..., size: _Optional[int] = ...) -> None: ...



from eolymp.atlas import permission_pb2 as _permission_pb2
from eolymp.atlas import problem_pb2 as _problem_pb2
from eolymp.atlas import score_pb2 as _score_pb2
from eolymp.atlas import submission_pb2 as _submission_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PermissionsDeletedEvent(_message.Message):
    __slots__ = ["problem_id", "user_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    user_id: str
    def __init__(self, problem_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class PermissionsUpdatedEvent(_message.Message):
    __slots__ = ["permission", "problem_id"]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    permission: _permission_pb2.Permission
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ..., permission: _Optional[_Union[_permission_pb2.Permission, _Mapping]] = ...) -> None: ...

class ProblemDeletedEvent(_message.Message):
    __slots__ = ["problem_id"]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    problem_id: str
    def __init__(self, problem_id: _Optional[str] = ...) -> None: ...

class ProblemUpdatedEvent(_message.Message):
    __slots__ = ["problem"]
    PROBLEM_FIELD_NUMBER: _ClassVar[int]
    problem: _problem_pb2.Problem
    def __init__(self, problem: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...

class ScoreUpdatedEvent(_message.Message):
    __slots__ = ["score"]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    score: _score_pb2.Score
    def __init__(self, score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...

class SubmissionCompleteEvent(_message.Message):
    __slots__ = ["submission", "update"]
    SUBMISSION_FIELD_NUMBER: _ClassVar[int]
    UPDATE_FIELD_NUMBER: _ClassVar[int]
    submission: _submission_pb2.Submission
    update: bool
    def __init__(self, submission: _Optional[_Union[_submission_pb2.Submission, _Mapping]] = ..., update: bool = ...) -> None: ...



from eolymp.judge import score_pb2 as _score_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Result(_message.Message):
    __slots__ = ["contest_id", "name", "out_of_competition", "participant_id", "rank", "rank_lower", "score"]
    CONTEST_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OUT_OF_COMPETITION_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    RANK_FIELD_NUMBER: _ClassVar[int]
    RANK_LOWER_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    contest_id: str
    name: str
    out_of_competition: bool
    participant_id: str
    rank: int
    rank_lower: int
    score: _score_pb2.Score
    def __init__(self, participant_id: _Optional[str] = ..., contest_id: _Optional[str] = ..., name: _Optional[str] = ..., out_of_competition: bool = ..., rank: _Optional[int] = ..., rank_lower: _Optional[int] = ..., score: _Optional[_Union[_score_pb2.Score, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/block.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.typewriter import inline_pb2 as eolymp_dot_typewriter_dot_inline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/typewriter/block.proto\x12\x11\x65olymp.typewriter\x1a\x1e\x65olymp/typewriter/inline.proto\"7\n\tContainer\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"\xa2\x10\n\x05\x42lock\x12\x37\n\tparagraph\x18\x01 \x01(\x0b\x32\".eolymp.typewriter.Block.ParagraphH\x00\x12\x31\n\x06layout\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Block.LayoutH\x00\x12-\n\x04\x63ode\x18\x03 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.CodeH\x00\x12-\n\x04math\x18\x04 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.MathH\x00\x12/\n\x05image\x18\x05 \x01(\x0b\x32\x1e.eolymp.typewriter.Block.ImageH\x00\x12\x33\n\x07heading\x18\x06 \x01(\x0b\x32 .eolymp.typewriter.Block.HeadingH\x00\x12-\n\x04list\x18\x07 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.ListH\x00\x12/\n\x05\x65mbed\x18\x08 \x01(\x0b\x32\x1e.eolymp.typewriter.Block.EmbedH\x00\x12/\n\x05table\x18\t \x01(\x0b\x32\x1e.eolymp.typewriter.Block.TableH\x00\x12\x31\n\x06widget\x18\n \x01(\x0b\x32\x1f.eolymp.typewriter.Block.WidgetH\x00\x1a\x38\n\tParagraph\x12+\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\xeb\x03\n\x06Layout\x12<\n\tdirection\x18\x01 \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Direction\x12>\n\x0b\x61lign_items\x18\n \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12@\n\ralign_content\x18\x0b \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12@\n\rjustify_items\x18\x0c \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12\x42\n\x0fjustify_content\x18\r \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12\x0b\n\x03gap\x18\x14 \x01(\r\x12\x0f\n\x07padding\x18\x15 \x03(\r\x12.\n\x08\x63hildren\x18\x64 \x03(\x0b\x32\x1c.eolymp.typewriter.Container\" \n\tDirection\x12\x07\n\x03ROW\x10\x00\x12\n\n\x06\x43OLUMN\x10\x01\"+\n\tAlignment\x12\t\n\x05START\x10\x00\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x07\n\x03\x45ND\x10\x02\x1a\xc9\x01\n\x04List\x12\x32\n\x05style\x18\x01 \x01(\x0e\x32#.eolymp.typewriter.Block.List.Style\x12\x34\n\x08\x63hildren\x18\n \x03(\x0b\x32\".eolymp.typewriter.Block.List.Item\x1a\x32\n\x04Item\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"#\n\x05Style\x12\r\n\tUNORDERED\x10\x00\x12\x0b\n\x07ORDERED\x10\x01\x1a\x61\n\x05Image\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\x0b\n\x03\x61lt\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\x12\x10\n\x08zoomable\x18\x06 \x01(\x08\x1a\x45\n\x07Heading\x12\r\n\x05level\x18\x01 \x01(\r\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x1a%\n\x04\x43ode\x12\x0c\n\x04lang\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x1aq\n\x05\x45mbed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x34\n\x06values\x18\x02 \x03(\x0b\x32$.eolymp.typewriter.Block.Embed.Value\x1a$\n\x05Value\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x8e\x02\n\x05Table\x12\x35\n\x06header\x18\x01 \x01(\x0e\x32%.eolymp.typewriter.Block.Table.Header\x12\x34\n\x08\x63hildren\x18\n \x03(\x0b\x32\".eolymp.typewriter.Block.Table.Row\x1a<\n\x03Row\x12\x35\n\x08\x63hildren\x18\x01 \x03(\x0b\x32#.eolymp.typewriter.Block.Table.Cell\x1a\x32\n\x04\x43\x65ll\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"&\n\x06Header\x12\x0e\n\nHORIZONTAL\x10\x00\x12\x0c\n\x08VERTICAL\x10\x01\x1a\xba\x01\n\x06Widget\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\nattributes\x18\x02 \x03(\x0b\x32/.eolymp.typewriter.Block.Widget.AttributesEntry\x12*\n\x08\x63hildren\x18\n \x03(\x0b\x32\x18.eolymp.typewriter.Block\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04nodeB7Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.typewriter.block_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriter'
  _BLOCK_WIDGET_ATTRIBUTESENTRY._options = None
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CONTAINER._serialized_start=84
  _CONTAINER._serialized_end=139
  _BLOCK._serialized_start=142
  _BLOCK._serialized_end=2224
  _BLOCK_PARAGRAPH._serialized_start=651
  _BLOCK_PARAGRAPH._serialized_end=707
  _BLOCK_LAYOUT._serialized_start=710
  _BLOCK_LAYOUT._serialized_end=1201
  _BLOCK_LAYOUT_DIRECTION._serialized_start=1124
  _BLOCK_LAYOUT_DIRECTION._serialized_end=1156
  _BLOCK_LAYOUT_ALIGNMENT._serialized_start=1158
  _BLOCK_LAYOUT_ALIGNMENT._serialized_end=1201
  _BLOCK_LIST._serialized_start=1204
  _BLOCK_LIST._serialized_end=1405
  _BLOCK_LIST_ITEM._serialized_start=1318
  _BLOCK_LIST_ITEM._serialized_end=1368
  _BLOCK_LIST_STYLE._serialized_start=1370
  _BLOCK_LIST_STYLE._serialized_end=1405
  _BLOCK_IMAGE._serialized_start=1407
  _BLOCK_IMAGE._serialized_end=1504
  _BLOCK_HEADING._serialized_start=1506
  _BLOCK_HEADING._serialized_end=1575
  _BLOCK_MATH._serialized_start=1577
  _BLOCK_MATH._serialized_end=1600
  _BLOCK_CODE._serialized_start=1602
  _BLOCK_CODE._serialized_end=1639
  _BLOCK_EMBED._serialized_start=1641
  _BLOCK_EMBED._serialized_end=1754
  _BLOCK_EMBED_VALUE._serialized_start=1718
  _BLOCK_EMBED_VALUE._serialized_end=1754
  _BLOCK_TABLE._serialized_start=1757
  _BLOCK_TABLE._serialized_end=2027
  _BLOCK_TABLE_ROW._serialized_start=1875
  _BLOCK_TABLE_ROW._serialized_end=1935
  _BLOCK_TABLE_CELL._serialized_start=1937
  _BLOCK_TABLE_CELL._serialized_end=1987
  _BLOCK_TABLE_HEADER._serialized_start=1989
  _BLOCK_TABLE_HEADER._serialized_end=2027
  _BLOCK_WIDGET._serialized_start=2030
  _BLOCK_WIDGET._serialized_end=2216
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_start=2167
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_end=2216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testset.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.atlas import feedback_pb2 as eolymp_dot_atlas_dot_feedback__pb2
from eolymp.atlas import scoring_pb2 as eolymp_dot_atlas_dot_scoring__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/atlas/testset.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/resource.proto\x1a\x1b\x65olymp/atlas/feedback.proto\x1a\x1a\x65olymp/atlas/scoring.proto\"\xa2\x02\n\x07Testset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\r\x12\x12\n\ntime_limit\x18\n \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0b \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\x0c \x01(\x04\x12\x14\n\x0c\x64\x65pendencies\x18\x14 \x03(\r\x12/\n\x0cscoring_mode\x18\x1e \x01(\x0e\x32\x19.eolymp.atlas.ScoringMode\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18( \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy:\'\xb2\xe3\n#\xba\xe3\n\x07testset\xc2\xe3\n\x14\x65olymp.atlas.ProblemB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testset_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _TESTSET._options = None
  _TESTSET._serialized_options = b'\262\343\n#\272\343\n\007testset\302\343\n\024eolymp.atlas.Problem'
  _TESTSET._serialized_start=137
  _TESTSET._serialized_end=427
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import resource_pb2 as _resource_pb2
from eolymp.atlas import attachment_pb2 as _attachment_pb2
from eolymp.atlas import permission_pb2 as _permission_pb2
from eolymp.atlas import problem_pb2 as _problem_pb2
from eolymp.atlas import statement_pb2 as _statement_pb2
from eolymp.atlas import template_pb2 as _template_pb2
from eolymp.atlas import test_pb2 as _test_pb2
from eolymp.atlas import testset_pb2 as _testset_pb2
from eolymp.executor import interactor_pb2 as _interactor_pb2
from eolymp.executor import verifier_pb2 as _verifier_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Change(_message.Message):
    __slots__ = ["create_attachment", "create_problem", "create_statement", "create_template", "create_test", "create_testset", "delete_attachment", "delete_problem", "delete_statement", "delete_template", "delete_test", "delete_testset", "grant_permission", "id", "ip_address", "problem_id", "revoke_permission", "timestamp", "update_attachment", "update_interactor", "update_problem", "update_statement", "update_template", "update_test", "update_testset", "update_verifier", "user_id"]
    class CreateAttachment(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _attachment_pb2.Attachment
        def __init__(self, after: _Optional[_Union[_attachment_pb2.Attachment, _Mapping]] = ...) -> None: ...
    class CreateProblem(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _problem_pb2.Problem
        def __init__(self, after: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...
    class CreateStatement(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _statement_pb2.Statement
        def __init__(self, after: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...
    class CreateTemplate(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _template_pb2.Template
        def __init__(self, after: _Optional[_Union[_template_pb2.Template, _Mapping]] = ...) -> None: ...
    class CreateTest(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _test_pb2.Test
        def __init__(self, after: _Optional[_Union[_test_pb2.Test, _Mapping]] = ...) -> None: ...
    class CreateTestset(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _testset_pb2.Testset
        def __init__(self, after: _Optional[_Union[_testset_pb2.Testset, _Mapping]] = ...) -> None: ...
    class DeleteAttachment(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _attachment_pb2.Attachment
        def __init__(self, before: _Optional[_Union[_attachment_pb2.Attachment, _Mapping]] = ...) -> None: ...
    class DeleteProblem(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _problem_pb2.Problem
        def __init__(self, before: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...
    class DeleteStatement(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _statement_pb2.Statement
        def __init__(self, before: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...
    class DeleteTemplate(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _template_pb2.Template
        def __init__(self, before: _Optional[_Union[_template_pb2.Template, _Mapping]] = ...) -> None: ...
    class DeleteTest(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _test_pb2.Test
        def __init__(self, before: _Optional[_Union[_test_pb2.Test, _Mapping]] = ...) -> None: ...
    class DeleteTestset(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _testset_pb2.Testset
        def __init__(self, before: _Optional[_Union[_testset_pb2.Testset, _Mapping]] = ...) -> None: ...
    class GrantPermission(_message.Message):
        __slots__ = ["after"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        after: _permission_pb2.Permission
        def __init__(self, after: _Optional[_Union[_permission_pb2.Permission, _Mapping]] = ...) -> None: ...
    class RevokePermission(_message.Message):
        __slots__ = ["before"]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        before: _permission_pb2.Permission
        def __init__(self, before: _Optional[_Union[_permission_pb2.Permission, _Mapping]] = ...) -> None: ...
    class UpdateAttachment(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _attachment_pb2.Attachment
        before: _attachment_pb2.Attachment
        def __init__(self, before: _Optional[_Union[_attachment_pb2.Attachment, _Mapping]] = ..., after: _Optional[_Union[_attachment_pb2.Attachment, _Mapping]] = ...) -> None: ...
    class UpdateInteractor(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _interactor_pb2.Interactor
        before: _interactor_pb2.Interactor
        def __init__(self, before: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ..., after: _Optional[_Union[_interactor_pb2.Interactor, _Mapping]] = ...) -> None: ...
    class UpdateProblem(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _problem_pb2.Problem
        before: _problem_pb2.Problem
        def __init__(self, before: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ..., after: _Optional[_Union[_problem_pb2.Problem, _Mapping]] = ...) -> None: ...
    class UpdateStatement(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _statement_pb2.Statement
        before: _statement_pb2.Statement
        def __init__(self, before: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ..., after: _Optional[_Union[_statement_pb2.Statement, _Mapping]] = ...) -> None: ...
    class UpdateTemplate(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _template_pb2.Template
        before: _template_pb2.Template
        def __init__(self, before: _Optional[_Union[_template_pb2.Template, _Mapping]] = ..., after: _Optional[_Union[_template_pb2.Template, _Mapping]] = ...) -> None: ...
    class UpdateTest(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _test_pb2.Test
        before: _test_pb2.Test
        def __init__(self, before: _Optional[_Union[_test_pb2.Test, _Mapping]] = ..., after: _Optional[_Union[_test_pb2.Test, _Mapping]] = ...) -> None: ...
    class UpdateTestset(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _testset_pb2.Testset
        before: _testset_pb2.Testset
        def __init__(self, before: _Optional[_Union[_testset_pb2.Testset, _Mapping]] = ..., after: _Optional[_Union[_testset_pb2.Testset, _Mapping]] = ...) -> None: ...
    class UpdateVerifier(_message.Message):
        __slots__ = ["after", "before"]
        AFTER_FIELD_NUMBER: _ClassVar[int]
        BEFORE_FIELD_NUMBER: _ClassVar[int]
        after: _verifier_pb2.Verifier
        before: _verifier_pb2.Verifier
        def __init__(self, before: _Optional[_Union[_verifier_pb2.Verifier, _Mapping]] = ..., after: _Optional[_Union[_verifier_pb2.Verifier, _Mapping]] = ...) -> None: ...
    CREATE_ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    CREATE_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    CREATE_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    CREATE_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CREATE_TESTSET_FIELD_NUMBER: _ClassVar[int]
    CREATE_TEST_FIELD_NUMBER: _ClassVar[int]
    DELETE_ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    DELETE_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    DELETE_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    DELETE_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    DELETE_TESTSET_FIELD_NUMBER: _ClassVar[int]
    DELETE_TEST_FIELD_NUMBER: _ClassVar[int]
    GRANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
    REVOKE_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    UPDATE_ATTACHMENT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_INTERACTOR_FIELD_NUMBER: _ClassVar[int]
    UPDATE_PROBLEM_FIELD_NUMBER: _ClassVar[int]
    UPDATE_STATEMENT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TESTSET_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TEST_FIELD_NUMBER: _ClassVar[int]
    UPDATE_VERIFIER_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    create_attachment: Change.CreateAttachment
    create_problem: Change.CreateProblem
    create_statement: Change.CreateStatement
    create_template: Change.CreateTemplate
    create_test: Change.CreateTest
    create_testset: Change.CreateTestset
    delete_attachment: Change.DeleteAttachment
    delete_problem: Change.DeleteProblem
    delete_statement: Change.DeleteStatement
    delete_template: Change.DeleteTemplate
    delete_test: Change.DeleteTest
    delete_testset: Change.DeleteTestset
    grant_permission: Change.GrantPermission
    id: str
    ip_address: str
    problem_id: str
    revoke_permission: Change.RevokePermission
    timestamp: _timestamp_pb2.Timestamp
    update_attachment: Change.UpdateAttachment
    update_interactor: Change.UpdateInteractor
    update_problem: Change.UpdateProblem
    update_statement: Change.UpdateStatement
    update_template: Change.UpdateTemplate
    update_test: Change.UpdateTest
    update_testset: Change.UpdateTestset
    update_verifier: Change.UpdateVerifier
    user_id: str
    def __init__(self, id: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., ip_address: _Optional[str] = ..., user_id: _Optional[str] = ..., problem_id: _Optional[str] = ..., create_problem: _Optional[_Union[Change.CreateProblem, _Mapping]] = ..., update_problem: _Optional[_Union[Change.UpdateProblem, _Mapping]] = ..., update_verifier: _Optional[_Union[Change.UpdateVerifier, _Mapping]] = ..., update_interactor: _Optional[_Union[Change.UpdateInteractor, _Mapping]] = ..., delete_problem: _Optional[_Union[Change.DeleteProblem, _Mapping]] = ..., create_statement: _Optional[_Union[Change.CreateStatement, _Mapping]] = ..., update_statement: _Optional[_Union[Change.UpdateStatement, _Mapping]] = ..., delete_statement: _Optional[_Union[Change.DeleteStatement, _Mapping]] = ..., create_testset: _Optional[_Union[Change.CreateTestset, _Mapping]] = ..., update_testset: _Optional[_Union[Change.UpdateTestset, _Mapping]] = ..., delete_testset: _Optional[_Union[Change.DeleteTestset, _Mapping]] = ..., create_test: _Optional[_Union[Change.CreateTest, _Mapping]] = ..., update_test: _Optional[_Union[Change.UpdateTest, _Mapping]] = ..., delete_test: _Optional[_Union[Change.DeleteTest, _Mapping]] = ..., create_template: _Optional[_Union[Change.CreateTemplate, _Mapping]] = ..., update_template: _Optional[_Union[Change.UpdateTemplate, _Mapping]] = ..., delete_template: _Optional[_Union[Change.DeleteTemplate, _Mapping]] = ..., create_attachment: _Optional[_Union[Change.CreateAttachment, _Mapping]] = ..., update_attachment: _Optional[_Union[Change.UpdateAttachment, _Mapping]] = ..., delete_attachment: _Optional[_Union[Change.DeleteAttachment, _Mapping]] = ..., grant_permission: _Optional[_Union[Change.GrantPermission, _Mapping]] = ..., revoke_permission: _Optional[_Union[Change.RevokePermission, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/typewriter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/typewriter/typewriter.proto\x12\x11\x65olymp.typewriter\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\"2\n\x10UploadAssetInput\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"!\n\x11UploadAssetOutput\x12\x0c\n\x04link\x18\x01 \x01(\t2\xa5\x01\n\nTypewriter\x12\x96\x01\n\x0bUploadAsset\x12#.eolymp.typewriter.UploadAssetInput\x1a$.eolymp.typewriter.UploadAssetOutput\"<\x82\xe3\n\x1a\x8a\xe3\n\x16typewriter:asset:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\nd\x82\xd3\xe4\x93\x02\t\"\x07/assetsB7Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.typewriter.typewriter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriter'
  _TYPEWRITER.methods_by_name['UploadAsset']._options = None
  _TYPEWRITER.methods_by_name['UploadAsset']._serialized_options = b'\202\343\n\032\212\343\n\026typewriter:asset:write\352\342\n\013\365\342\n\000\000\000@\370\342\nd\202\323\344\223\002\t\"\007/assets'
  _UPLOADASSETINPUT._serialized_start=156
  _UPLOADASSETINPUT._serialized_end=206
  _UPLOADASSETOUTPUT._serialized_start=208
  _UPLOADASSETOUTPUT._serialized_end=241
  _TYPEWRITER._serialized_start=244
  _TYPEWRITER._serialized_end=409
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Project(_message.Message):
    __slots__ = ["author_id", "created_on", "ern", "id", "labels", "name", "runtime", "target", "target_ern", "updated_on", "visibility"]
    class Visibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    class Target(_message.Message):
        __slots__ = ["problem_id", "space_id"]
        PROBLEM_ID_FIELD_NUMBER: _ClassVar[int]
        SPACE_ID_FIELD_NUMBER: _ClassVar[int]
        problem_id: str
        space_id: str
        def __init__(self, space_id: _Optional[str] = ..., problem_id: _Optional[str] = ...) -> None: ...
    AUTHOR_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_ON_FIELD_NUMBER: _ClassVar[int]
    ERN_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NONE: Project.Visibility
    PRIVATE: Project.Visibility
    PUBLIC: Project.Visibility
    RUNTIME_FIELD_NUMBER: _ClassVar[int]
    TARGET_ERN_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    UPDATED_ON_FIELD_NUMBER: _ClassVar[int]
    VISIBILITY_FIELD_NUMBER: _ClassVar[int]
    author_id: str
    created_on: _timestamp_pb2.Timestamp
    ern: str
    id: str
    labels: _containers.RepeatedScalarFieldContainer[str]
    name: str
    runtime: str
    target: Project.Target
    target_ern: str
    updated_on: _timestamp_pb2.Timestamp
    visibility: Project.Visibility
    def __init__(self, ern: _Optional[str] = ..., id: _Optional[str] = ..., name: _Optional[str] = ..., runtime: _Optional[str] = ..., visibility: _Optional[_Union[Project.Visibility, str]] = ..., author_id: _Optional[str] = ..., created_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., target: _Optional[_Union[Project.Target, _Mapping]] = ..., target_ern: _Optional[str] = ..., labels: _Optional[_Iterable[str]] = ...) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.cognito import access_key_pb2 as _access_key_pb2
from eolymp.cognito import entitlement_pb2 as _entitlement_pb2
from eolymp.cognito import quota_pb2 as _quota_pb2
from eolymp.cognito import user_pb2 as _user_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompleteRecoverInput(_message.Message):
    __slots__ = ["password", "secret", "user_id"]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    password: str
    secret: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., secret: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CompleteRecoverOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateAccessKeyInput(_message.Message):
    __slots__ = ["expires_in", "name", "scope"]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    expires_in: int
    name: str
    scope: str
    def __init__(self, name: _Optional[str] = ..., scope: _Optional[str] = ..., expires_in: _Optional[int] = ...) -> None: ...

class CreateAccessKeyOutput(_message.Message):
    __slots__ = ["key_id", "secret"]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    secret: str
    def __init__(self, key_id: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class CreateAuthorizationInput(_message.Message):
    __slots__ = ["client_id", "code_challenge", "code_challenge_method", "redirect_uri", "response_type", "scope", "state"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_FIELD_NUMBER: _ClassVar[int]
    CODE_CHALLENGE_METHOD_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_TYPE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    code_challenge: str
    code_challenge_method: str
    redirect_uri: str
    response_type: str
    scope: str
    state: str
    def __init__(self, client_id: _Optional[str] = ..., code_challenge: _Optional[str] = ..., code_challenge_method: _Optional[str] = ..., redirect_uri: _Optional[str] = ..., response_type: _Optional[str] = ..., scope: _Optional[str] = ..., state: _Optional[str] = ...) -> None: ...

class CreateAuthorizationOutput(_message.Message):
    __slots__ = ["authorization_code", "redirect_uri"]
    AUTHORIZATION_CODE_FIELD_NUMBER: _ClassVar[int]
    REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
    authorization_code: str
    redirect_uri: str
    def __init__(self, authorization_code: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...

class CreateTokenInput(_message.Message):
    __slots__ = ["client_id", "client_secret", "code", "code_verifier", "grant_type", "password", "refresh_token", "scope", "username"]
    class GrantType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    AUTHORIZATION_CODE: CreateTokenInput.GrantType
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_VERIFIER_FIELD_NUMBER: _ClassVar[int]
    GOOGLE_CODE: CreateTokenInput.GrantType
    GRANT_TYPE_FIELD_NUMBER: _ClassVar[int]
    NONE: CreateTokenInput.GrantType
    PASSWORD: CreateTokenInput.GrantType
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN: CreateTokenInput.GrantType
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: str
    code: str
    code_verifier: str
    grant_type: CreateTokenInput.GrantType
    password: str
    refresh_token: str
    scope: str
    username: str
    def __init__(self, grant_type: _Optional[_Union[CreateTokenInput.GrantType, str]] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., code: _Optional[str] = ..., code_verifier: _Optional[str] = ..., scope: _Optional[str] = ..., refresh_token: _Optional[str] = ...) -> None: ...

class CreateTokenOutput(_message.Message):
    __slots__ = ["expires_at", "refresh_token", "scopes", "token", "type", "user_id", "username"]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    expires_at: _timestamp_pb2.Timestamp
    refresh_token: str
    scopes: _containers.RepeatedScalarFieldContainer[str]
    token: str
    type: str
    user_id: str
    username: str
    def __init__(self, token: _Optional[str] = ..., type: _Optional[str] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ..., refresh_token: _Optional[str] = ..., user_id: _Optional[str] = ..., username: _Optional[str] = ...) -> None: ...

class CreateUserInput(_message.Message):
    __slots__ = ["birthday", "captcha", "country", "email", "full_name", "locale", "password", "username"]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FULL_NAME_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    birthday: str
    captcha: str
    country: str
    email: str
    full_name: str
    locale: str
    password: str
    username: str
    def __init__(self, username: _Optional[str] = ..., full_name: _Optional[str] = ..., email: _Optional[str] = ..., password: _Optional[str] = ..., country: _Optional[str] = ..., birthday: _Optional[str] = ..., captcha: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class CreateUserOutput(_message.Message):
    __slots__ = ["email_confirmation_hint", "user_id"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., email_confirmation_hint: _Optional[str] = ...) -> None: ...

class DeleteAccessKeyInput(_message.Message):
    __slots__ = ["key_id"]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    key_id: str
    def __init__(self, key_id: _Optional[str] = ...) -> None: ...

class DeleteAccessKeyOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeUserInput(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class DescribeUserOutput(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class IntrospectQuotaInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectQuotaOutput(_message.Message):
    __slots__ = ["contests_per_user", "participants_per_contest", "problems_per_contest", "problems_per_user"]
    CONTESTS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_CONTEST_FIELD_NUMBER: _ClassVar[int]
    PROBLEMS_PER_USER_FIELD_NUMBER: _ClassVar[int]
    contests_per_user: _quota_pb2.Quota
    participants_per_contest: _quota_pb2.Quota
    problems_per_contest: _quota_pb2.Quota
    problems_per_user: _quota_pb2.Quota
    def __init__(self, contests_per_user: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., problems_per_contest: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., participants_per_contest: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ..., problems_per_user: _Optional[_Union[_quota_pb2.Quota, _Mapping]] = ...) -> None: ...

class IntrospectRolesInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectRolesOutput(_message.Message):
    __slots__ = ["roles"]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, roles: _Optional[_Iterable[str]] = ...) -> None: ...

class IntrospectTokenInput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class IntrospectTokenOutput(_message.Message):
    __slots__ = ["active", "expires_at", "scopes", "token", "type", "user_id", "username"]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    active: bool
    expires_at: _timestamp_pb2.Timestamp
    scopes: _containers.RepeatedScalarFieldContainer[str]
    token: str
    type: str
    user_id: str
    username: str
    def __init__(self, active: bool = ..., token: _Optional[str] = ..., type: _Optional[str] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ..., user_id: _Optional[str] = ..., username: _Optional[str] = ...) -> None: ...

class IntrospectUserInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class IntrospectUserOutput(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class ListAccessKeysInput(_message.Message):
    __slots__ = ["offset", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListAccessKeysOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_access_key_pb2.AccessKey]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_access_key_pb2.AccessKey, _Mapping]]] = ...) -> None: ...

class ListEntitlementsInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListEntitlementsOutput(_message.Message):
    __slots__ = ["entitlements"]
    ENTITLEMENTS_FIELD_NUMBER: _ClassVar[int]
    entitlements: _containers.RepeatedScalarFieldContainer[_entitlement_pb2.Entitlement]
    def __init__(self, entitlements: _Optional[_Iterable[_Union[_entitlement_pb2.Entitlement, str]]] = ...) -> None: ...

class ListRolesInput(_message.Message):
    __slots__ = ["user_id"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ...) -> None: ...

class ListRolesOutput(_message.Message):
    __slots__ = ["roles"]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, roles: _Optional[_Iterable[str]] = ...) -> None: ...

class ListUsersInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "username"]
        ID_FIELD_NUMBER: _ClassVar[int]
        USERNAME_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        username: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., username: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListUsersInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListUsersInput.Filter, _Mapping]] = ...) -> None: ...

class ListUsersOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_user_pb2.User]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_user_pb2.User, _Mapping]]] = ...) -> None: ...

class NotifyUserInput(_message.Message):
    __slots__ = ["parameters", "template", "user_id"]
    class ParametersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    parameters: _containers.ScalarMap[str, str]
    template: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., template: _Optional[str] = ..., parameters: _Optional[_Mapping[str, str]] = ...) -> None: ...

class NotifyUserOutput(_message.Message):
    __slots__ = ["notification_id"]
    NOTIFICATION_ID_FIELD_NUMBER: _ClassVar[int]
    notification_id: str
    def __init__(self, notification_id: _Optional[str] = ...) -> None: ...

class RevokeTokenInput(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class RevokeTokenOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SelfDestructInput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class SelfDestructOutput(_message.Message):
    __slots__ = ["delete_on"]
    DELETE_ON_FIELD_NUMBER: _ClassVar[int]
    delete_on: _timestamp_pb2.Timestamp
    def __init__(self, delete_on: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SignoutInput(_message.Message):
    __slots__ = ["everywhere"]
    EVERYWHERE_FIELD_NUMBER: _ClassVar[int]
    everywhere: bool
    def __init__(self, everywhere: bool = ...) -> None: ...

class SignoutOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class StartRecoveryInput(_message.Message):
    __slots__ = ["captcha", "email", "locale"]
    CAPTCHA_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    captcha: str
    email: str
    locale: str
    def __init__(self, email: _Optional[str] = ..., captcha: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class StartRecoveryOutput(_message.Message):
    __slots__ = ["email_recovery_hint"]
    EMAIL_RECOVERY_HINT_FIELD_NUMBER: _ClassVar[int]
    email_recovery_hint: str
    def __init__(self, email_recovery_hint: _Optional[str] = ...) -> None: ...

class UpdateEmailInput(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class UpdateEmailOutput(_message.Message):
    __slots__ = ["email_confirmation_hint"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    def __init__(self, email_confirmation_hint: _Optional[str] = ...) -> None: ...

class UpdatePasswordInput(_message.Message):
    __slots__ = ["current_password", "new_password"]
    CURRENT_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    NEW_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    current_password: str
    new_password: str
    def __init__(self, current_password: _Optional[str] = ..., new_password: _Optional[str] = ...) -> None: ...

class UpdatePasswordOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdatePictureInput(_message.Message):
    __slots__ = ["data", "filename", "offset_x", "offset_y", "size"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    OFFSET_X_FIELD_NUMBER: _ClassVar[int]
    OFFSET_Y_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    filename: str
    offset_x: int
    offset_y: int
    size: int
    def __init__(self, filename: _Optional[str] = ..., data: _Optional[bytes] = ..., offset_x: _Optional[int] = ..., offset_y: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class UpdatePictureOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateProfileInput(_message.Message):
    __slots__ = ["birthday", "city", "company", "country", "email", "name", "occupation", "patch", "username"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    BIRTHDAY: UpdateProfileInput.Patch
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    CITY: UpdateProfileInput.Patch
    CITY_FIELD_NUMBER: _ClassVar[int]
    COMPANY: UpdateProfileInput.Patch
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    COUNTRY: UpdateProfileInput.Patch
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    EMAIL: UpdateProfileInput.Patch
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateProfileInput.Patch
    NAME_FIELD_NUMBER: _ClassVar[int]
    OCCUPATION: UpdateProfileInput.Patch
    OCCUPATION_FIELD_NUMBER: _ClassVar[int]
    PATCH_FIELD_NUMBER: _ClassVar[int]
    USERNAME: UpdateProfileInput.Patch
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    birthday: str
    city: str
    company: str
    country: str
    email: str
    name: str
    occupation: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateProfileInput.Patch]
    username: str
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateProfileInput.Patch, str]]] = ..., username: _Optional[str] = ..., email: _Optional[str] = ..., name: _Optional[str] = ..., company: _Optional[str] = ..., occupation: _Optional[str] = ..., country: _Optional[str] = ..., city: _Optional[str] = ..., birthday: _Optional[str] = ...) -> None: ...

class UpdateProfileOutput(_message.Message):
    __slots__ = ["email_confirmation_hint"]
    EMAIL_CONFIRMATION_HINT_FIELD_NUMBER: _ClassVar[int]
    email_confirmation_hint: str
    def __init__(self, email_confirmation_hint: _Optional[str] = ...) -> None: ...

class UpdateRolesInput(_message.Message):
    __slots__ = ["roles", "user_id"]
    ROLES_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedScalarFieldContainer[str]
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., roles: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateRolesOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class VerifyEmailInput(_message.Message):
    __slots__ = ["secret", "user_id"]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    secret: str
    user_id: str
    def __init__(self, user_id: _Optional[str] = ..., secret: _Optional[str] = ...) -> None: ...

class VerifyEmailOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/helpdesk/events.proto\x12\x0f\x65olymp.helpdesk\x1a\x1e\x65olymp/helpdesk/document.proto\"C\n\x14\x44ocumentCreatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentUpdatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentDeletedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.DocumentB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _DOCUMENTCREATEDEVENT._serialized_start=81
  _DOCUMENTCREATEDEVENT._serialized_end=148
  _DOCUMENTUPDATEDEVENT._serialized_start=150
  _DOCUMENTUPDATEDEVENT._serialized_end=217
  _DOCUMENTDELETEDEVENT._serialized_start=219
  _DOCUMENTDELETEDEVENT._serialized_end=286
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.workspace import file_pb2 as eolymp_dot_workspace_dot_file__pb2
from eolymp.workspace import project_pb2 as eolymp_dot_workspace_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/workspace/workspace.proto\x12\x10\x65olymp.workspace\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/workspace/file.proto\x1a\x1e\x65olymp/workspace/project.proto\"?\n\x14\x44\x65scribeProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"C\n\x15\x44\x65scribeProjectOutput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"\x87\x01\n\x11ListProjectsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.workspace.ListProjectsInput.Filter\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"M\n\x12ListProjectsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.workspace.Project\"@\n\x12\x43reateProjectInput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\">\n\x13\x43reateProjectOutput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"i\n\x12UpdateProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12*\n\x07project\x18\x03 \x01(\x0b\x32\x19.eolymp.workspace.Project\"\x15\n\x13UpdateProjectOutput\"=\n\x12\x44\x65leteProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteProjectOutput\"W\n\x0eListFilesInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"G\n\x0fListFilesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.workspace.File\"G\n\x11\x44\x65scribeFileInput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\":\n\x12\x44\x65scribeFileOutput\x12$\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x16.eolymp.workspace.File\"Y\n\x0fUploadFileInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"$\n\x10UploadFileOutput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\"E\n\x0fRemoveFileInput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x12\n\x10RemoveFileOutput2\xe6\x0c\n\tWorkspace\x12\xba\x01\n\x0f\x44\x65scribeProject\x12&.eolymp.workspace.DescribeProjectInput\x1a\'.eolymp.workspace.DescribeProjectOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\"\x12 /workspace/projects/{project_id}\x12\xa3\x01\n\x0cListProjects\x12#.eolymp.workspace.ListProjectsInput\x1a$.eolymp.workspace.ListProjectsOutput\"H\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x15\x12\x13/workspace/projects\x12\xa7\x01\n\rCreateProject\x12$.eolymp.workspace.CreateProjectInput\x1a%.eolymp.workspace.CreateProjectOutput\"I\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\"\x13/workspace/projects\x12\xb4\x01\n\rUpdateProject\x12$.eolymp.workspace.UpdateProjectInput\x1a%.eolymp.workspace.UpdateProjectOutput\"V\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\" /workspace/projects/{project_id}\x12\xb4\x01\n\rDeleteProject\x12$.eolymp.workspace.DeleteProjectInput\x1a%.eolymp.workspace.DeleteProjectOutput\"V\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"* /workspace/projects/{project_id}\x12\xad\x01\n\tListFiles\x12 .eolymp.workspace.ListFilesInput\x1a!.eolymp.workspace.ListFilesOutput\"[\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/workspace/projects/{project_id}/files\x12\xbe\x01\n\x0c\x44\x65scribeFile\x12#.eolymp.workspace.DescribeFileInput\x1a$.eolymp.workspace.DescribeFileOutput\"c\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02/\x12-/workspace/projects/{project_id}/files/{name}\x12\xb1\x01\n\nUploadFile\x12!.eolymp.workspace.UploadFileInput\x1a\".eolymp.workspace.UploadFileOutput\"\\\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02(\"&/workspace/projects/{project_id}/files\x12\xb8\x01\n\nRemoveFile\x12!.eolymp.workspace.RemoveFileInput\x1a\".eolymp.workspace.RemoveFileOutput\"c\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02/*-/workspace/projects/{project_id}/files/{name}B5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.workspace_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _WORKSPACE.methods_by_name['DescribeProject']._options = None
  _WORKSPACE.methods_by_name['DescribeProject']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\"\022 /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['ListProjects']._options = None
  _WORKSPACE.methods_by_name['ListProjects']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\025\022\023/workspace/projects'
  _WORKSPACE.methods_by_name['CreateProject']._options = None
  _WORKSPACE.methods_by_name['CreateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\025\"\023/workspace/projects'
  _WORKSPACE.methods_by_name['UpdateProject']._options = None
  _WORKSPACE.methods_by_name['UpdateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\" /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['DeleteProject']._options = None
  _WORKSPACE.methods_by_name['DeleteProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"* /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['ListFiles']._options = None
  _WORKSPACE.methods_by_name['ListFiles']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/workspace/projects/{project_id}/files'
  _WORKSPACE.methods_by_name['DescribeFile']._options = None
  _WORKSPACE.methods_by_name['DescribeFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002/\022-/workspace/projects/{project_id}/files/{name}'
  _WORKSPACE.methods_by_name['UploadFile']._options = None
  _WORKSPACE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002(\"&/workspace/projects/{project_id}/files'
  _WORKSPACE.methods_by_name['RemoveFile']._options = None
  _WORKSPACE.methods_by_name['RemoveFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002/*-/workspace/projects/{project_id}/files/{name}'
  _DESCRIBEPROJECTINPUT._serialized_start=214
  _DESCRIBEPROJECTINPUT._serialized_end=277
  _DESCRIBEPROJECTOUTPUT._serialized_start=279
  _DESCRIBEPROJECTOUTPUT._serialized_end=346
  _LISTPROJECTSINPUT._serialized_start=349
  _LISTPROJECTSINPUT._serialized_end=484
  _LISTPROJECTSINPUT_FILTER._serialized_start=461
  _LISTPROJECTSINPUT_FILTER._serialized_end=484
  _LISTPROJECTSOUTPUT._serialized_start=486
  _LISTPROJECTSOUTPUT._serialized_end=563
  _CREATEPROJECTINPUT._serialized_start=565
  _CREATEPROJECTINPUT._serialized_end=629
  _CREATEPROJECTOUTPUT._serialized_start=631
  _CREATEPROJECTOUTPUT._serialized_end=693
  _UPDATEPROJECTINPUT._serialized_start=695
  _UPDATEPROJECTINPUT._serialized_end=800
  _UPDATEPROJECTOUTPUT._serialized_start=802
  _UPDATEPROJECTOUTPUT._serialized_end=823
  _DELETEPROJECTINPUT._serialized_start=825
  _DELETEPROJECTINPUT._serialized_end=886
  _DELETEPROJECTOUTPUT._serialized_start=888
  _DELETEPROJECTOUTPUT._serialized_end=909
  _LISTFILESINPUT._serialized_start=911
  _LISTFILESINPUT._serialized_end=998
  _LISTFILESOUTPUT._serialized_start=1000
  _LISTFILESOUTPUT._serialized_end=1071
  _DESCRIBEFILEINPUT._serialized_start=1073
  _DESCRIBEFILEINPUT._serialized_end=1144
  _DESCRIBEFILEOUTPUT._serialized_start=1146
  _DESCRIBEFILEOUTPUT._serialized_end=1204
  _UPLOADFILEINPUT._serialized_start=1206
  _UPLOADFILEINPUT._serialized_end=1295
  _UPLOADFILEOUTPUT._serialized_start=1297
  _UPLOADFILEOUTPUT._serialized_end=1333
  _REMOVEFILEINPUT._serialized_start=1335
  _REMOVEFILEINPUT._serialized_end=1404
  _REMOVEFILEOUTPUT._serialized_start=1406
  _REMOVEFILEOUTPUT._serialized_end=1424
  _WORKSPACE._serialized_start=1427
  _WORKSPACE._serialized_end=3065
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import resource_pb2 as _resource_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class File(_message.Message):
    __slots__ = ["content", "ern", "name"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    ERN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    ern: str
    name: str
    def __init__(self, ern: _Optional[str] = ..., name: _Optional[str] = ..., content: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/member.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a!eolymp/annotations/resource.proto\x1a eolymp/community/attribute.proto\"\xf3\x05\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x12\n\nregistered\x18\x04 \x01(\x08\x12\x0f\n\x07staffed\x18\x05 \x01(\x08\x12\r\n\x05ghost\x18\x07 \x01(\x08\x12\x1a\n\x12out_of_competition\x18\x08 \x01(\x08\x12/\n\x06status\x18\x06 \x01(\x0e\x32\x1f.eolymp.community.Member.Status\x12\x35\n\nidentities\x18\n \x03(\x0b\x32!.eolymp.community.Member.Identity\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\x1a\xb2\x01\n\x08Identity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08nickname\x18\x05 \x01(\t\x12\x0f\n\x07picture\x18\x06 \x01(\t\x12\r\n\x05\x65mail\x18\x07 \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x08 \x01(\x08\x12\x0f\n\x07profile\x18\t \x01(\t\x12\x10\n\x08password\x18\x64 \x01(\t\x1a\x84\x01\n\x05Value\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12\x38\n\x0e\x61ttribute_type\x18\x02 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\x14\n\x0cvalue_string\x18\n \x01(\t\x12\x14\n\x0cvalue_number\x18\x0b \x01(\x05\"b\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\r\n\tUNSTAFFED\x10\x01\x12\x10\n\x0cUNREGISTERED\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08INACTIVE\x10\x04\x12\t\n\x05GHOST\x10\x05:\'\xb2\xe3\n#\xba\xe3\n\x06member\xc2\xe3\n\x15\x65olymp.universe.SpaceB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _MEMBER._options = None
  _MEMBER._serialized_options = b'\262\343\n#\272\343\n\006member\302\343\n\025eolymp.universe.Space'
  _MEMBER._serialized_start=121
  _MEMBER._serialized_end=876
  _MEMBER_IDENTITY._serialized_start=422
  _MEMBER_IDENTITY._serialized_end=600
  _MEMBER_VALUE._serialized_start=603
  _MEMBER_VALUE._serialized_end=735
  _MEMBER_STATUS._serialized_start=737
  _MEMBER_STATUS._serialized_end=835
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/permission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/atlas/permission.proto\x12\x0c\x65olymp.atlas\"\x87\x01\n\nPermission\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12+\n\x04role\x18\x03 \x01(\x0e\x32\x1d.eolymp.atlas.Permission.Role\"\'\n\x04Role\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05OWNER\x10\x01\x12\n\n\x06\x45\x44ITOR\x10\x02\x42-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.permission_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _PERMISSION._serialized_start=48
  _PERMISSION._serialized_end=183
  _PERMISSION_ROLE._serialized_start=144
  _PERMISSION_ROLE._serialized_end=183
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/activity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/judge/activity.proto\x12\x0c\x65olymp.judge\x1a!eolymp/annotations/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x04\n\x08\x41\x63tivity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.eolymp.judge.Activity.Type\x12-\n\x06status\x18\x03 \x01(\x0e\x32\x1d.eolymp.judge.Activity.Status\x12\x12\n\ncontest_id\x18\x05 \x01(\t\x12\x15\n\rscoreboard_id\x18\x64 \x01(\t\x12\x12\n\nproblem_id\x18\x65 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bprogress_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63omplete_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08progress\x18\x14 \x01(\r\x12\r\n\x05total\x18\x15 \x01(\r\x12\r\n\x05\x65rror\x18\x1e \x01(\t\"<\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0ePROBLEM_RETEST\x10\x01\x12\x16\n\x12SCOREBOARD_REBUILD\x10\x02\"H\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\t\n\x05\x45RROR\x10\x04:(\xb2\xe3\n$\xba\xe3\n\x08\x61\x63tivity\xc2\xe3\n\x14\x65olymp.judge.ContestB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.activity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ACTIVITY._options = None
  _ACTIVITY._serialized_options = b'\262\343\n$\272\343\n\010activity\302\343\n\024eolymp.judge.Contest'
  _ACTIVITY._serialized_start=114
  _ACTIVITY._serialized_end=723
  _ACTIVITY_TYPE._serialized_start=547
  _ACTIVITY_TYPE._serialized_end=607
  _ACTIVITY_STATUS._serialized_start=609
  _ACTIVITY_STATUS._serialized_end=681
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.helpdesk import document_pb2 as _document_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDocumentInput(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class CreateDocumentOutput(_message.Message):
    __slots__ = ["document_id"]
    DOCUMENT_ID_FIELD_NUMBER: _ClassVar[int]
    document_id: str
    def __init__(self, document_id: _Optional[str] = ...) -> None: ...

class DeleteDocumentInput(_message.Message):
    __slots__ = ["document_id"]
    DOCUMENT_ID_FIELD_NUMBER: _ClassVar[int]
    document_id: str
    def __init__(self, document_id: _Optional[str] = ...) -> None: ...

class DeleteDocumentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeDocumentInput(_message.Message):
    __slots__ = ["document_id"]
    DOCUMENT_ID_FIELD_NUMBER: _ClassVar[int]
    document_id: str
    def __init__(self, document_id: _Optional[str] = ...) -> None: ...

class DescribeDocumentOutput(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class DescribePathInput(_message.Message):
    __slots__ = ["path", "preferred_locales"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_LOCALES_FIELD_NUMBER: _ClassVar[int]
    path: str
    preferred_locales: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, path: _Optional[str] = ..., preferred_locales: _Optional[_Iterable[str]] = ...) -> None: ...

class DescribePathOutput(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class ListDocumentsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "locale", "path", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListDocumentsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListDocumentsInput.Filter, _Mapping]] = ...) -> None: ...

class ListDocumentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_document_pb2.Document]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_document_pb2.Document, _Mapping]]] = ...) -> None: ...

class ListParentsInput(_message.Message):
    __slots__ = ["path", "preferred_locales"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_LOCALES_FIELD_NUMBER: _ClassVar[int]
    path: str
    preferred_locales: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, path: _Optional[str] = ..., preferred_locales: _Optional[_Iterable[str]] = ...) -> None: ...

class ListParentsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_document_pb2.Document]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_document_pb2.Document, _Mapping]]] = ...) -> None: ...

class ListPathsInput(_message.Message):
    __slots__ = ["filters", "offset", "preferred_locales", "size"]
    class Filter(_message.Message):
        __slots__ = ["label", "path", "query"]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        label: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        path: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., path: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., label: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    PREFERRED_LOCALES_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListPathsInput.Filter
    offset: int
    preferred_locales: _containers.RepeatedScalarFieldContainer[str]
    size: int
    def __init__(self, preferred_locales: _Optional[_Iterable[str]] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListPathsInput.Filter, _Mapping]] = ...) -> None: ...

class ListPathsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_document_pb2.Document]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_document_pb2.Document, _Mapping]]] = ...) -> None: ...

class UpdateDocumentInput(_message.Message):
    __slots__ = ["document", "document_id"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    DOCUMENT_ID_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    document_id: str
    def __init__(self, document_id: _Optional[str] = ..., document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class UpdateDocumentOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.workspace import project_pb2 as eolymp_dot_workspace_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/workspace/events.proto\x12\x10\x65olymp.workspace\x1a\x1e\x65olymp/workspace/project.proto\"A\n\x13ProjectCreatedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"A\n\x13ProjectUpdatedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"A\n\x13ProjectDeletedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.ProjectB5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _PROJECTCREATEDEVENT._serialized_start=83
  _PROJECTCREATEDEVENT._serialized_end=148
  _PROJECTUPDATEDEVENT._serialized_start=150
  _PROJECTUPDATEDEVENT._serialized_end=215
  _PROJECTDELETEDEVENT._serialized_start=217
  _PROJECTDELETEDEVENT._serialized_end=282
# @@protoc_insertion_point(module_scope)



from eolymp.helpdesk import document_pb2 as _document_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DocumentCreatedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class DocumentDeletedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...

class DocumentUpdatedEvent(_message.Message):
    __slots__ = ["document"]
    DOCUMENT_FIELD_NUMBER: _ClassVar[int]
    document: _document_pb2.Document
    def __init__(self, document: _Optional[_Union[_document_pb2.Document, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/task.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/executor/task.proto\x12\x0f\x65olymp.executor\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\"\xdf\x07\n\x04Task\x12\x11\n\treference\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\r\x12\r\n\x04lang\x18\xe8\x07 \x01(\t\x12\x0f\n\x07runtime\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x13\n\x0buse_file_io\x18\x0c \x01(\x08\x12!\n\x19redirect_stderr_to_stdout\x18\r \x01(\x08\x12\x1d\n\x15use_workspace_archive\x18\x0f \x01(\x08\x12\x39\n\rpreconditions\x18( \x03(\x0b\x32\".eolymp.executor.Task.Precondition\x12\x35\n\x0b\x63onstraints\x18\x14 \x03(\x0b\x32 .eolymp.executor.Task.Constraint\x12+\n\x08verifier\x18\x18 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12/\n\ninteractor\x18\x19 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12\'\n\x04runs\x18\x1e \x03(\x0b\x32\x19.eolymp.executor.Task.Run\x12)\n\x05\x66iles\x18\x32 \x03(\x0b\x32\x1a.eolymp.executor.Task.File\x1a(\n\x04\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsource_ern\x18\x02 \x01(\t\x1a\xd1\x01\n\x03Run\x12\x11\n\treference\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05\x64\x65\x62ug\x18\x03 \x01(\x08\x12\x0c\n\x04\x63ost\x18\x04 \x01(\x02\x12\x0e\n\x06labels\x18\x1e \x03(\t\x12\x19\n\x0finput_object_id\x18\n \x01(\tH\x00\x12\x17\n\rinput_content\x18\x0b \x01(\tH\x00\x12\x1a\n\x10\x61nswer_object_id\x18\x14 \x01(\tH\x01\x12\x18\n\x0e\x61nswer_content\x18\x15 \x01(\tH\x01\x42\x07\n\x05inputB\x08\n\x06\x61nswer\x1ai\n\x0cPrecondition\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\x12\n\ndepends_on\x18\n \x03(\t\x12\x17\n\x0fstop_on_failure\x18\x0b \x01(\x08\x12\x1a\n\x12max_execution_time\x18\x0c \x01(\r\x1a\x8d\x01\n\nConstraint\x12\x10\n\x08selector\x18\x01 \x03(\t\x12\r\n\x05\x61\x63tor\x18\x02 \x01(\t\x12\x17\n\x0fwall_time_limit\x18\n \x01(\r\x12\x16\n\x0e\x63pu_time_limit\x18\x0b \x01(\r\x12\x14\n\x0cmemory_limit\x18\x0c \x01(\x04\x12\x17\n\x0f\x66ile_size_limit\x18\r \x01(\x04\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.task_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _TASK._serialized_start=114
  _TASK._serialized_end=1105
  _TASK_FILE._serialized_start=602
  _TASK_FILE._serialized_end=642
  _TASK_RUN._serialized_start=645
  _TASK_RUN._serialized_end=854
  _TASK_PRECONDITION._serialized_start=856
  _TASK_PRECONDITION._serialized_end=961
  _TASK_CONSTRAINT._serialized_start=964
  _TASK_CONSTRAINT._serialized_end=1105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/reply.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x65olymp/judge/reply.proto\x12\x0c\x65olymp.judge\x1a!eolymp/annotations/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x01\n\x05Reply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12\x11\n\x07user_id\x18\x03 \x01(\tH\x00\x12\x13\n\tmember_id\x18\x04 \x01(\tH\x00\x12\x0f\n\x07message\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp:$\xb2\xe3\n \xba\xe3\n\x05reply\xc2\xe3\n\x13\x65olymp.judge.TicketB\x08\n\x06\x61uthorB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.reply_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _REPLY._options = None
  _REPLY._serialized_options = b'\262\343\n \272\343\n\005reply\302\343\n\023eolymp.judge.Ticket'
  _REPLY._serialized_start=111
  _REPLY._serialized_end=316
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

BLOCK_USERS: Entitlement
DESCRIPTOR: _descriptor.FileDescriptor
MANAGE_ROLES: Entitlement
VIEW_BLOCKED_PROFILE: Entitlement
VIEW_PRIVATE_DATA: Entitlement
VIEW_PUBLIC_PROFILE: Entitlement

class Entitlement(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.workspace import file_pb2 as _file_pb2
from eolymp.workspace import project_pb2 as _project_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateProjectInput(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...

class CreateProjectOutput(_message.Message):
    __slots__ = ["project_ern", "project_id"]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_ern: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ...) -> None: ...

class DeleteProjectInput(_message.Message):
    __slots__ = ["project_ern", "project_id"]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_ern: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ...) -> None: ...

class DeleteProjectOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeFileInput(_message.Message):
    __slots__ = ["file_ern", "name", "project_id"]
    FILE_ERN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    file_ern: str
    name: str
    project_id: str
    def __init__(self, file_ern: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class DescribeFileOutput(_message.Message):
    __slots__ = ["file"]
    FILE_FIELD_NUMBER: _ClassVar[int]
    file: _file_pb2.File
    def __init__(self, file: _Optional[_Union[_file_pb2.File, _Mapping]] = ...) -> None: ...

class DescribeProjectInput(_message.Message):
    __slots__ = ["project_ern", "project_id"]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project_ern: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ...) -> None: ...

class DescribeProjectOutput(_message.Message):
    __slots__ = ["project"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    def __init__(self, project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...

class ListFilesInput(_message.Message):
    __slots__ = ["offset", "project_ern", "project_id", "size"]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    offset: int
    project_ern: str
    project_id: str
    size: int
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ...) -> None: ...

class ListFilesOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_file_pb2.File]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_file_pb2.File, _Mapping]]] = ...) -> None: ...

class ListProjectsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["query"]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        query: str
        def __init__(self, query: _Optional[str] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListProjectsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListProjectsInput.Filter, _Mapping]] = ...) -> None: ...

class ListProjectsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_project_pb2.Project]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_project_pb2.Project, _Mapping]]] = ...) -> None: ...

class RemoveFileInput(_message.Message):
    __slots__ = ["file_ern", "name", "project_id"]
    FILE_ERN_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    file_ern: str
    name: str
    project_id: str
    def __init__(self, file_ern: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class RemoveFileOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateProjectInput(_message.Message):
    __slots__ = ["project", "project_ern", "project_id"]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    project: _project_pb2.Project
    project_ern: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ..., project: _Optional[_Union[_project_pb2.Project, _Mapping]] = ...) -> None: ...

class UpdateProjectOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UploadFileInput(_message.Message):
    __slots__ = ["content", "name", "project_ern", "project_id"]
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ERN_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    content: bytes
    name: str
    project_ern: str
    project_id: str
    def __init__(self, project_id: _Optional[str] = ..., project_ern: _Optional[str] = ..., name: _Optional[str] = ..., content: _Optional[bytes] = ...) -> None: ...

class UploadFileOutput(_message.Message):
    __slots__ = ["file_ern"]
    FILE_ERN_FIELD_NUMBER: _ClassVar[int]
    file_ern: str
    def __init__(self, file_ern: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

ALL: ScoringMode
BEST: ScoringMode
DESCRIPTOR: _descriptor.FileDescriptor
EACH: ScoringMode
NO_SCORE: ScoringMode
WORST: ScoringMode

class ScoringMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/problem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.atlas import feedback_pb2 as eolymp_dot_atlas_dot_feedback__pb2
from eolymp.typewriter import block_pb2 as eolymp_dot_typewriter_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65olymp/judge/problem.proto\x12\x0c\x65olymp.judge\x1a!eolymp/annotations/resource.proto\x1a\x1b\x65olymp/atlas/feedback.proto\x1a\x1d\x65olymp/typewriter/block.proto\"\xe0\x05\n\x07Problem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\r\n\x05index\x18\x02 \x01(\r\x12\r\n\x05score\x18\x03 \x01(\x02\x12\x0f\n\x07\x62\x61se_id\x18\x04 \x01(\t\x12\x12\n\ncontest_id\x18\x05 \x01(\t\x12\x35\n\x0f\x66\x65\x65\x64\x62\x61\x63k_policy\x18\n \x01(\x0e\x32\x1c.eolymp.atlas.FeedbackPolicy\x12\x13\n\ntime_limit\x18\xc8\x01 \x01(\r\x12\x15\n\x0cmemory_limit\x18\xc9\x01 \x01(\x04\x12\x18\n\x0f\x66ile_size_limit\x18\xca\x01 \x01(\x04\x12\x15\n\x0csubmit_limit\x18\xcb\x01 \x01(\r\x12\x1e\n\x15score_by_best_testset\x18\xd2\x01 \x01(\x08\x1a\xfd\x01\n\tStatement\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x32\n\x0c\x63ontent_rich\x18\x04 \x01(\x0b\x32\x1c.eolymp.typewriter.Container\x12\x36\n\x06\x66ormat\x18\x05 \x01(\x0e\x32&.eolymp.judge.Problem.Statement.Format\x12\x15\n\rdownload_link\x18\x06 \x01(\t\"=\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03\x12\x08\n\x04RICH\x10\x04\x1ah\n\x04Test\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x65xample\x18\x02 \x01(\x08\x12\x17\n\x0finput_object_id\x18\x03 \x01(\t\x12\x18\n\x10\x61nswer_object_id\x18\x04 \x01(\t\x12\r\n\x05score\x18\x05 \x01(\x02\x1a\x34\n\nAttachment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04link\x18\x04 \x01(\t:$\xb2\xe3\n \xba\xe3\n\x04task\xc2\xe3\n\x14\x65olymp.judge.ContestB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.problem_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _PROBLEM._options = None
  _PROBLEM._serialized_options = b'\262\343\n \272\343\n\004task\302\343\n\024eolymp.judge.Contest'
  _PROBLEM._serialized_start=140
  _PROBLEM._serialized_end=876
  _PROBLEM_STATEMENT._serialized_start=425
  _PROBLEM_STATEMENT._serialized_end=678
  _PROBLEM_STATEMENT_FORMAT._serialized_start=617
  _PROBLEM_STATEMENT_FORMAT._serialized_end=678
  _PROBLEM_TEST._serialized_start=680
  _PROBLEM_TEST._serialized_end=784
  _PROBLEM_ATTACHMENT._serialized_start=786
  _PROBLEM_ATTACHMENT._serialized_end=838
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/category.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/category.proto\x12\x0c\x65olymp.atlas\"\xd1\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07visible\x18\n \x01(\x08\x12\r\n\x05index\x18\x0b \x01(\r\x12\x11\n\tparent_id\x18\x0c \x01(\t\x12\r\n\x05image\x18\x14 \x01(\t\x12\x38\n\x0c\x64\x65scriptions\x18\x1e \x03(\x0b\x32\".eolymp.atlas.Category.Description\x1a=\n\x0b\x44\x65scription\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.category_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CATEGORY._serialized_start=46
  _CATEGORY._serialized_end=255
  _CATEGORY_DESCRIPTION._serialized_start=194
  _CATEGORY_DESCRIPTION._serialized_end=255
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IdentityProvider(_message.Message):
    __slots__ = []
    class OIDC(_message.Message):
        __slots__ = ["authorize_endpoint", "client_id", "client_secret", "issuer", "keys_endpoint", "redirect_uri", "token_endpoint", "userinfo_endpoint"]
        AUTHORIZE_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
        CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
        ISSUER_FIELD_NUMBER: _ClassVar[int]
        KEYS_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        REDIRECT_URI_FIELD_NUMBER: _ClassVar[int]
        TOKEN_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        USERINFO_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
        authorize_endpoint: str
        client_id: str
        client_secret: str
        issuer: str
        keys_endpoint: str
        redirect_uri: str
        token_endpoint: str
        userinfo_endpoint: str
        def __init__(self, client_id: _Optional[str] = ..., client_secret: _Optional[str] = ..., issuer: _Optional[str] = ..., authorize_endpoint: _Optional[str] = ..., token_endpoint: _Optional[str] = ..., keys_endpoint: _Optional[str] = ..., userinfo_endpoint: _Optional[str] = ..., redirect_uri: _Optional[str] = ...) -> None: ...
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/statement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.typewriter import block_pb2 as eolymp_dot_typewriter_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/atlas/statement.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/resource.proto\x1a\x1d\x65olymp/typewriter/block.proto\"\xe0\x02\n\tStatement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x32\n\x0c\x63ontent_rich\x18\x08 \x01(\x0b\x32\x1c.eolymp.typewriter.Container\x12\x15\n\rdownload_link\x18\x07 \x01(\t\x12.\n\x06\x66ormat\x18\x06 \x01(\x0e\x32\x1e.eolymp.atlas.Statement.Format\x12\x0e\n\x06\x61uthor\x18\x65 \x01(\t\x12\x0e\n\x06source\x18\x66 \x01(\t\"=\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03\x12\x08\n\x04RICH\x10\x04:)\xb2\xe3\n%\xba\xe3\n\tstatement\xc2\xe3\n\x14\x65olymp.atlas.ProblemB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.statement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _STATEMENT._options = None
  _STATEMENT._serialized_options = b'\262\343\n%\272\343\n\tstatement\302\343\n\024eolymp.atlas.Problem'
  _STATEMENT._serialized_start=113
  _STATEMENT._serialized_end=465
  _STATEMENT_FORMAT._serialized_start=361
  _STATEMENT_FORMAT._serialized_end=422
# @@protoc_insertion_point(module_scope)
